@@ -185,6 +185,7 @@ int main(int argc, char **argv)
     {
       GtkWidget *dialog;
       gint response;
+      GdkDisplay *display = gdk_display_get_default ();
       
       /* Read the preferences */
       screenshooter_read_rc_file (rc_file, sd, FALSE);
@@ -192,12 +193,19 @@ int main(int argc, char **argv)
       /* Set the dialog up */
       dialog = screenshooter_dialog_new (sd, FALSE);
       
+      gtk_window_set_type_hint(GTK_WINDOW (dialog), 
+                               GDK_WINDOW_TYPE_HINT_NORMAL);
+      
       /* Run the dialog and destroy it, so that it's not grabbed in active
          window mode */
       response = gtk_dialog_run (GTK_DIALOG (dialog));
       
       gtk_widget_destroy (dialog);
       
+      gdk_display_sync (display);
+      
+      sleep (1);
+                  
       if (response == GTK_RESPONSE_OK)
         {
           gchar *screenshot_path = NULL;
@@ -239,6 +247,7 @@ int main(int argc, char **argv)
           
           /* Save preferences */     
           screenshooter_write_rc_file (rc_file, sd);
+          
         }
     }
   
